"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* tslint:disable:no-unused-expression no-empty no-console */
var chai = require("chai");
var chaiAsPromised = require("chai-as-promised");
var nock = require("nock");
var request_1 = require("./request");
chai.use(chaiAsPromised);
var expect = chai.expect;
describe("Request", function () {
    var request;
    var PORT = 1024 + Math.floor(Math.random() * 5000);
    var URL = "http://localhost:" + PORT;
    var URLSECURE = "https://localhost:" + PORT;
    beforeEach(function () { return (request = new request_1.Request()); });
    context("#send", function () {
        afterEach(function () { return nock.cleanAll(); });
        describe("Promise", function () {
            it("Should return a promise", function () {
                nock(URL)
                    .get("/")
                    .reply(200);
                var r = request.send(request_1.HTTPMethod.GET, URL);
                return Promise.all([
                    expect(r).is.ok,
                    expect(r.then).is.ok,
                    expect(r.then).is.a("function"),
                    expect(r).to.be.fulfilled,
                ]);
            });
            it("Should resolve when request succeeds with response body", function () {
                var BODY = "body";
                nock(URL)
                    .get("/")
                    .reply(200, BODY);
                var p = request.send(request_1.HTTPMethod.GET, URL);
                return Promise.all([
                    expect(p).to.be.fulfilled,
                    expect(p).to.eventually.be.equal(BODY),
                ]);
            });
            it("Should reject when request fails with error message", function () {
                var ERROR = "error";
                nock(URL)
                    .get("/")
                    .reply(400, ERROR);
                var p = request.send(request_1.HTTPMethod.GET, URL);
                return expect(p).to.be.rejectedWith(ERROR);
            });
        });
        describe("Headers", function () {
            it("Should have Pact headers are sent with every request", function () {
                nock(URL)
                    .matchHeader("X-Pact-Mock-Service", "true")
                    .get("/")
                    .reply(200);
                return expect(request.send(request_1.HTTPMethod.GET, URL)).to.be.fulfilled;
            });
        });
        describe("SSL", function () {
            it("Should ignore self signed certificate errors", function () {
                nock(URLSECURE)
                    .matchHeader("X-Pact-Mock-Service", "true")
                    .get("/")
                    .reply(200);
                return expect(request.send(request_1.HTTPMethod.GET, URLSECURE)).to.be.fulfilled;
            });
        });
    });
});
//# sourceMappingURL=request.spec.js.map